var __extends = this.__extends || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    __.prototype = b.prototype;
    d.prototype = new __();
};
var Tower = (function (_super) {
    __extends(Tower, _super);
    function Tower(gameplay, x, y) {
        _super.call(this, gameplay.game, x, y, "");
        this.range = Gameplay.minTowerRange;
        this.lastShot = 0;
        this.reloadTime = 1000;
        this.shotSpeed = 300;
        this.damageValue = 10;
        this.lvlDamage = 0;
        this.lvlRange = 0;
        this.lvlSpeed = 0;
        this.lvlReload = 0;
        this.gameplay = gameplay;
        gameplay.towerGroup.add(this);
        var towerSprite = gameplay.game.add.sprite(0, 0, "tower");
        towerSprite.anchor.set(0.5, 0.5);
        this.anchor.set(0.5, 0.5);
        this.fire = gameplay.game.add.sprite(0, -15, "fire");
        this.fire.scale.set(0.7, 0.7);
        gameplay.game.add.tween(this.fire.scale).to({ x: 1.1, y: 1.1 }, 500, Phaser.Easing.Linear.None, true, 0, -1, true);
        this.fire.anchor.set(0.5, 0.5);
        this.addChild(this.fire);
        this.addChild(towerSprite);
        this.infoText = gameplay.game.add.text(0, 35, this.getShortText(), { font: "10px Arial", fill: "#FFFFFF", align: "center" });
        this.infoText.anchor.set(0.5, 0.5);
        this.addChild(this.infoText);
    }
    Tower.prototype.increaseDamage = function () {
        this.lvlDamage++;
        this.damageValue = 10 + Math.round(Math.pow(1.6, this.lvlDamage) * 5);
        this.infoText.text = this.getShortText();
    };
    Tower.prototype.increaseRange = function () {
        this.lvlRange++;
        this.range = Gameplay.minTowerRange + this.lvlRange * 25;
        this.infoText.text = this.getShortText();
    };
    Tower.prototype.increaseSpeed = function () {
        this.lvlSpeed++;
        this.shotSpeed = 300 + this.lvlSpeed * 30;
        this.infoText.text = this.getShortText();
    };
    Tower.prototype.increaseReload = function () {
        this.lvlReload++;
        this.reloadTime = 1000 - this.lvlReload * 80;
        this.infoText.text = this.getShortText();
    };
    Tower.prototype.getInfoText = function () {
        return "Damage: " + this.damageValue + "\nReloadtime: " + this.reloadTime + "\nSpeed: " + this.shotSpeed + "\nRange: " + this.range;
    };
    Tower.prototype.getShortText = function () {
        return (this.lvlDamage + 1) + "/" + (this.lvlReload + 1) + "/" + (this.lvlSpeed + 1) + "/" + (this.lvlRange + 1);
    };
    Tower.prototype.update = function () {
        this.fire.angle += 5;
        if (this.gameplay.game.time.now - this.lastShot > this.reloadTime) {
            for (var i = 0; i < this.gameplay.creepGroup.children.length; i++) {
                var creep = this.gameplay.creepGroup.children[i];
                if (creep.alive && this.gameplay.game.physics.arcade.distanceBetween(this, creep) < this.range) {
                    this.lastShot = this.gameplay.game.time.now;
                    var bullet = this.gameplay.bulletGroup.getFirstDead();
                    if (bullet === null) {
                        bullet = new Bullet(this.gameplay, this.x, this.y - 20, this.damageValue);
                    }
                    else {
                        bullet.reset(this.x, this.y - 20);
                    }
                    bullet.scale.set(0.7, 0.7);
                    bullet.checkWorldBounds = true;
                    bullet.outOfBoundsKill = true;
                    this.gameplay.game.physics.arcade.enableBody(bullet);
                    this.gameplay.game.physics.arcade.moveToXY(bullet, creep.x, creep.y, this.shotSpeed);
                    this.gameplay.bulletGroup.add(bullet);
                    break;
                }
            }
        }
    };
    return Tower;
})(Phaser.Sprite);
var Bullet = (function (_super) {
    __extends(Bullet, _super);
    function Bullet(gameplay, x, y, damage) {
        _super.call(this, gameplay.game, x, y, "fire");
        gameplay.bulletGroup.add(this);
        this.damageValue = damage;
    }
    return Bullet;
})(Phaser.Sprite);
//# sourceMappingURL=tower.js.map